#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import json
import gettext
import traceback
from ikabot.config import *
from ikabot.helpers.gui import *
from ikabot.helpers.varios import *
from ikabot.helpers.botComm import *
from ikabot.helpers.pedirInfo import *
from ikabot.helpers.process import set_child_mode
from ikabot.helpers.getJson import getCiudad
from ikabot.helpers.signals import setInfoSignal

t = gettext.translation('activarMilagro',
                        localedir,
                        languages=idiomas,
                        fallback=True)
_ = t.gettext

def obtenerMilagrosDisponibles(s):
	idsIslas = getIdsOfIslands(s)
	islas = []
	for idIsla in idsIslas:
		html = s.get(urlIsla + idIsla)
		isla = getIsla(html)
		isla['activable'] = False
		islas.append(isla)

	ids, citys = getIdsOfCities(s)
	for ciudad in citys:
		city = citys[ciudad]
		wonder = [ isla['wonder'] for isla in islas if city['coords'] == '[{}:{}] '.format(isla['x'], isla['y']) ][0]
		if wonder in [ isla['wonder'] for isla in islas if isla['activable'] ]:
			continue

		html = s.get(urlCiudad + str(city['id']))
		ciudad = getCiudad(html)

		if 'temple' in [ edificio['building'] for edificio in ciudad['position'] ]:
			for i in range( len( ciudad['position'] ) ):
				if ciudad['position'][i]['building'] == 'temple':
					ciudad['pos'] = str(i)
					break

			params = {"view": "temple", "cityId": ciudad['id'], "position": ciudad['pos'], "backgroundView": "city", "currentCityId": ciudad['id'], "actionRequest": s.token(), "ajax": "1"}
			data = s.post(params=params)
			data = json.loads(data, strict=False)
			available =  data[2][1]['js_WonderViewButton']['buttonState'] == 'enabled'
			if available is False:
				data = data[2][1]
				for elem in data:
					if 'countdown' in data[elem]:
						enddate     = data[elem]['countdown']['enddate']
						currentdate = data[elem]['countdown']['currentdate']
						break

			for isla in islas:
				if isla['id'] == ciudad['islandId']:
					isla['activable'] = True
					isla['ciudad'] = ciudad
					isla['available'] = available
					if available is False:
						isla['available_in'] = enddate - currentdate
					break

	return [ isla for isla in islas if isla['activable'] ]

def activarMilagroImpl(s, isla):
	params = {'action': 'CityScreen', 'cityId': isla['ciudad']['id'], 'function': 'activateWonder', 'position': isla['ciudad']['pos'], 'backgroundView': 'city', 'currentCityId': isla['ciudad']['id'], 'templateView': 'temple', 'actionRequest': s.token(), 'ajax': '1'}
	rta = s.post(params=params)
	return json.loads(rta, strict=False)

def elegir_isla(islas):
	print(_('¿Qué milagro quiere activar?'))
	i = 0
	print(_('(0) Salir'))
	for isla in islas:
		i += 1
		if isla['available']:
			print('({:d}) {}'.format(i, isla['wonderName']))
		else:
			print(_('({:d}) {} (disponible en: {})').format(i, isla['wonderName'], daysHoursMinutes(isla['available_in'])))

	index = read(min=0, max=i)
	if index == 0:
		return None
	isla = islas[index - 1]
	return isla

def activarMilagro(s,e,fd):
	sys.stdin = os.fdopen(fd)
	try:
		banner()

		islas = obtenerMilagrosDisponibles(s)
		if islas == []:
			print(_('No existen milagros disponibles.'))
			enter()
			e.set()
			return

		isla = elegir_isla(islas)
		if isla is None:
			e.set()
			return

		if isla['available']:
			print(_('\nSe activará el milagro {}').format(isla['wonderName']))
			print(_('¿Proceder? [Y/n]'))
			r = read(values=['y', 'Y', 'n', 'N', ''])
			if r.lower() == 'n':
				e.set()
				return

			rta = activarMilagroImpl(s, isla)

			if rta[1][1][0] == 'error':
				print(_('No se pudo activar el milagro {}.').format(isla['wonderName']))
				enter()
				e.set()
				return

			data = rta[2][1]
			for elem in data:
				if 'countdown' in data[elem]:
					enddate     = data[elem]['countdown']['enddate']
					currentdate = data[elem]['countdown']['currentdate']
					break
			wait_time = enddate - currentdate

			print(_('Se activó el milagro {}.').format(isla['wonderName']))
			enter()
			banner()

			while True:
				print(_('¿Desea activarlo nuevamente al terminar? [y/N]'))

				r = read(values=['y', 'Y', 'n', 'N', ''])
				if r.lower() != 'y':
					e.set()
					return

				iterations = read(msg=_('¿Cuántas veces?: '), digit=True, min=0)

				if iterations == 0:
					e.set()
					return

				duration = wait_time * iterations

				print(_('Terminará en:{}').format(daysHoursMinutes(duration)))

				print(_('¿Proceder? [Y/n]'))
				r = read(values=['y', 'Y', 'n', 'N', ''])
				if r.lower() == 'n':
					banner()
					continue
				break
		else:
			print(_('\nSe activará el milagro {} en {}').format(isla['wonderName'], daysHoursMinutes(isla['available_in'])))
			print(_('¿Proceder? [Y/n]'))
			rta = read(values=['y', 'Y', 'n', 'N', ''])
			if rta.lower() == 'n':
				e.set()
				return
			wait_time = isla['available_in']
			iterations = 1

			print(_('\nSe activará el milagro.'))
			enter()
			banner()

			while True:
				print(_('¿Desea activarlo nuevamente al terminar? [y/N]'))

				r = read(values=['y', 'Y', 'n', 'N', ''])
				again = r.lower() == 'y'
				if again is True:
					try:
						iterations = read(msg=_('¿Cuántas veces?: '), digit=True, min=0)
					except KeyboardInterrupt:
						iterations = 1
						break

					if iterations == 0:
						iterations = 1
						break

					iterations += 1
					duration = wait_time * iterations
					print(_('No se puede calcular el momento de finalización. (por lo menos: {}').format(daysHoursMinutes(duration)))
					print(_('¿Proceder? [Y/n]'))

					try:
						r = read(values=['y', 'Y', 'n', 'N', ''])
					except KeyboardInterrupt:
						iterations = 1
						break

					if r.lower() == 'n':
						iterations = 1
						banner()
						continue
				break
	except KeyboardInterrupt:
		e.set()
		return

	set_child_mode(s)
	e.set()

	info = _('\nActivo el milagro {} {:d} veces\n').format(isla['wonderName'], iterations)
	setInfoSignal(s, info)
	try:
		do_it(s, isla, iterations)
	except:
		msg = _('Error en:\n{}\nCausa:\n{}').format(info, traceback.format_exc())
		sendToBot(s, msg)
	finally:
		s.logout()

def wait_for_miracle(s, isla):
	while True:
		params = {"view": "temple", "cityId": isla['ciudad']['id'], "position": isla['ciudad']['pos'], "backgroundView": "city", "currentCityId": isla['ciudad']['id'], "actionRequest": s.token(), "ajax": "1"}
		data = s.post(params=params)
		data = json.loads(data, strict=False)
		data = data[2][1]

		for elem in data:
			if 'countdown' in data[elem]:
				enddate     = data[elem]['countdown']['enddate']
				currentdate = data[elem]['countdown']['currentdate']
				wait_time = enddate - currentdate
				break
		else:
			available = data['js_WonderViewButton']['buttonState'] == 'enabled'
			if available:
				return
			else:
				wait_time = 60

		msg = _('Espero {:d} segundos para activar el milagro {}').format(wait_time, isla['wonderName'])
		sendToBotDebug(s, msg, debugON_activarMilagro)
		wait(wait_time + 5)

def do_it(s, isla, iterations):

	for i in range(iterations):

		wait_for_miracle(s, isla)

		rta = activarMilagroImpl(s, isla)

		if rta[1][1][0] == 'error':
			msg = _('No se pudo activar el milagro {}.').format(isla['wonderName'])
			sendToBot(s, msg)
			return

		msg = _('Milagro {} activado con exito').format(isla['wonderName'])
		sendToBotDebug(s, msg, debugON_activarMilagro)



#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import re
import ikabot.config as config
from ikabot.helpers.process import run

def checkForUpdate():
	upgrade = run('python3 -m pip search ikabot').decode('utf-8').strip()
	if 'ikabot' not in upgrade:
		return

	upgrade = upgrade.split('\n')
	if len(upgrade) != 3:
		return

	upgrade = upgrade[2]
	match = re.search(r' +.*?: +(.*)', upgrade)
	if match is None:
		return

	new = match.group(1)
	config.update_msg = '[+] ikabot version {} is available\n'.format(new)



#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import os
import gettext
import multiprocessing
from ikabot.config import *
from ikabot.web.sesion import *
from ikabot.helpers.gui import *
from ikabot.funcion.donar import donar
from ikabot.funcion.update import update
from ikabot.helpers.pedirInfo import read
from ikabot.funcion.getStatus import getStatus
from ikabot.funcion.botDonador import botDonador
from ikabot.helpers.botComm import cargarTelegram
from ikabot.helpers.process import updateProcessList
from ikabot.funcion.subirEdificio import subirEdificios
from ikabot.funcion.buscarEspacios import buscarEspacios
from ikabot.funcion.alertarAtaques import alertarAtaques
from ikabot.funcion.modoVacaciones import modoVacaciones
from ikabot.funcion.activarMilagro import activarMilagro
from ikabot.funcion.entrenarTropas import entrenarTropas
from ikabot.funcion.entrenarFlotas import entrenarFlotas
from ikabot.funcion.venderRecursos import venderRecursos
from ikabot.funcion.checkForUpdate import checkForUpdate
from ikabot.funcion.repartirRecurso import repartirRecurso
from ikabot.funcion.alertarPocoVino import alertarPocoVino
from ikabot.funcion.comprarRecursos import comprarRecursos
from ikabot.funcion.entrarDiariamente import entrarDiariamente
from ikabot.funcion.menuRutaComercial import menuRutaComercial
from ikabot.funcion.construirEdificio import construirEdificio
from ikabot.funcion.movimientosNavales import movimientosNavales

t = gettext.translation('command_line', 
                        localedir, 
                        languages=idiomas,
                        fallback=True)
_ = t.gettext

def menu(s, checkUpdate=True):
	if checkUpdate:
		checkForUpdate()

	banner()

	processlist = updateProcessList(s)
	if len(processlist) > 0:
		print('Running tasks:')
		for process in processlist:
			if len(process['proxies']) == 0:
				proxy = ''
			else:
				proxy = 'proxy: ' + str(process['proxies'])

			print('- pid: {} task: {} {}'.format(process['pid'], process['action'], proxy))
		print('')

	menu_actions = [
					subirEdificios,
					menuRutaComercial,
					repartirRecurso,
					getStatus,
					donar,
					buscarEspacios,
					entrarDiariamente,
					alertarAtaques,
					botDonador,
					alertarPocoVino,
					comprarRecursos,
					venderRecursos,
					modoVacaciones,
					activarMilagro,
					entrenarTropas,
					entrenarFlotas,
					movimientosNavales,
					construirEdificio,
					update,
					cargarTelegram
					]

	print(_('(0)  Salir'))
	print(_('(1)  Lista de construcción'))
	print(_('(2)  Enviar recursos'))
	print(_('(3)  Distribuir recursos'))
	print(_('(4)  Estado de la cuenta'))
	print(_('(5)  Donar'))
	print(_('(6)  Buscar espacios nuevos'))
	print(_('(7)  Entrar diariamente'))
	print(_('(8)  Alertar ataques'))
	print(_('(9)  Donar automaticamente'))
	print(_('(10) Alertar poco vino'))
	print(_('(11) Comprar recursos'))
	print(_('(12) Vender recursos'))
	print(_('(13) Activar modo vacaciones'))
	print(_('(14) Activar milagro'))
	print(_('(15) Entrenar tropas'))
	print(_('(16) Entrenar flotas'))
	print(_('(17) Ver movimientos'))
	print(_('(18) Construir edificio'))
	print(_('(19) Actualizar Ikabot'))
	print(_('(20) Actualizar datos de Telegram'))

	entradas = len(menu_actions)
	eleccion = read(min=0, max=entradas)
	if eleccion != 0:
		try:
			eleccion -= 1
			event = multiprocessing.Event() #creates a new event
			process = multiprocessing.Process(target=menu_actions[eleccion], args=(s, event, sys.stdin.fileno()), name=menu_actions[eleccion].__name__ + s.username)
			process.start()
			processlist.append({'pid': process.pid, 'proxies': s.s.proxies, 'action': menu_actions[eleccion].__name__ })
			updateProcessList(s, programprocesslist = processlist)
			event.wait() #waits for the process to fire the event that's been given to it. When it does  this process gets back control of the command line and asks user for more input
		except KeyboardInterrupt:
			pass
		menu(s, checkUpdate=False)
	else:
		if isWindows:
			# in unix, you can exit ikabot and close the terminal and the processes will continue to execute
			# in windows, you can exit ikabot but if you close the terminal, the processes will die
			print('Closing this console will kill the processes.')
			enter()
		clear()
		os._exit(0) #kills the process which executes this statement, but it does not kill it's child processes

def inicializar():
	home = 'HOMEPATH' if isWindows else 'HOME'
	os.chdir(os.getenv(home))
	if not os.path.isfile(ikaFile):
		open(ikaFile, 'w')
		os.chmod(ikaFile, 0o600)

def start():
	inicializar()
	s = Sesion()
	try:
		menu(s)
	finally:
		clear()
		s.logout()

def main():
	try:
		start()
	except KeyboardInterrupt:
		clear()

if __name__ == '__main__':
	main()



#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import gettext
import traceback
from ikabot.config import *
from ikabot.helpers.gui import *
from ikabot.helpers.botComm import *
from ikabot.helpers.pedirInfo import *
from ikabot.helpers.planearViajes import executeRoutes
from ikabot.helpers.signals import setInfoSignal
from ikabot.helpers.getJson import getCiudad
from ikabot.helpers.process import set_child_mode
from ikabot.helpers.varios import addDot
from ikabot.helpers.recursos import *


def menuRutaComercial(s,e,fd):
	sys.stdin = os.fdopen(fd)
	t = gettext.translation('menuRutaComercial', 
	                        localedir, 
	                        languages=idiomas,
	                        fallback=True)
	_ = t.gettext
	try:
		rutas = []
		while True:

			banner()
			print(_('Ciudad de origen:'))
			try:
				ciudadO = chooseCity(s)
			except KeyboardInterrupt:
				if rutas:
					print(_('¿Enviar viajes? [Y/n]'))
					rta = read(values=['y', 'Y', 'n', 'N', ''])
					if rta.lower() != 'n':
						break
				e.set()
				return

			banner()
			print(_('Ciudad de destino'))
			ciudadD = chooseCity(s, foreign=True)
			idIsla = ciudadD['islandId']

			if ciudadO['id'] == ciudadD['id']:
				continue

			if ciudadD['propia']:
				mad = ciudadD['freeSpaceForResources'][0]
				vin = ciudadD['freeSpaceForResources'][1]
				mar = ciudadD['freeSpaceForResources'][2]
				cri = ciudadD['freeSpaceForResources'][3]
				azu = ciudadD['freeSpaceForResources'][4]

			resto = ciudadO['recursos']
			for ruta in rutas:
				(origen, destino, __, md, vn, mr, cr, az) = ruta
				if origen['id'] == ciudadO['id']:
					resto = (resto[0] - md, resto[1] - vn, resto[2] - mr, resto[3] - cr, resto[4] - az)
				if ciudadD['propia'] and destino['id'] == ciudadD['id']:
					mad = mad - md
					vin = vin - vn
					mar = mar - mr
					cri = cri - cr
					azu = azu - az

			banner()
			if ciudadD['propia']:
				msg = ''
				if resto[0] > mad:
					msg += _('{} más de madera\n').format(addDot(mad if mad > 0 else 0))
				if resto[1] > vin:
					msg += _('{} más de vino\n').format(addDot(vin if vin > 0 else 0))
				if resto[2] > mar:
					msg += _('{} más de marmol\n').format(addDot(mar if mar > 0 else 0))
				if resto[3] > cri:
					msg += _('{} más de cristal\n').format(addDot(cri if cri > 0 else 0))
				if resto[4] > azu:
					msg += _('{} más de azufre\n').format(addDot(azu if azu > 0 else 0))
				if msg:
					print(_('Solo puede almacenar:\n{}').format(msg))
			print(_('Disponible:'))
			print(_('Madera {} Vino {} Marmol {} Cristal {} Azufre {}').format(addDot(resto[0]), addDot(resto[1]), addDot(resto[2]), addDot(resto[3]), addDot(resto[4])))
			print(_('Enviar:'))
			try:
				md = askForValue(_(' Madera:'), resto[0])
				vn = askForValue(_('   Vino:'), resto[1])
				mr = askForValue(_(' Marmol:'), resto[2])
				cr = askForValue(_('Cristal:'), resto[3])
				az = askForValue(_(' Azufre:'), resto[4])
			except KeyboardInterrupt:
				continue
			if md + vn + mr + cr + az == 0:
				continue

			banner()
			print(_('Por enviar de {} a {}').format(ciudadO['cityName'], ciudadD['cityName']))
			enviado = ''
			if md:
				enviado += _('Madera:{} ').format(addDot(md))
			if vn:
				enviado += _('Vino:{} ').format(addDot(vn))
			if mr:
				enviado += _('Marmol:{} ').format(addDot(mr))
			if cr:
				enviado += _('Cristal:{} ').format(addDot(cr))
			if az:
				enviado += _('Azufre:{}').format(addDot(az))
			print(enviado)
			print(_('¿Proceder? [Y/n]'))
			rta = read(values=['y', 'Y', 'n', 'N', ''])
			if rta.lower() != 'n':
				ruta = (ciudadO, ciudadD, idIsla, md, vn, mr, cr, az)
				rutas.append(ruta)
				print(_('¿Realizar otro envio? [y/N]'))
				rta = read(values=['y', 'Y', 'n', 'N', ''])
				if rta.lower() != 'y':
					break
	except KeyboardInterrupt:
		e.set()
		return

	set_child_mode(s)
	e.set()

	info = _('\nRuta comercial\n')
	for ruta in rutas:
		(ciudadO, ciudadD, idIsla, md, vn, mr, cr, az) = ruta
		info = info + _('{} -> {}\nMadera: {} Vino: {} Marmol: {} Cristal: {} Azufre: {}\n').format(ciudadO['cityName'], ciudadD['cityName'], addDot(md), addDot(vn), addDot(mr), addDot(cr), addDot(az))

	setInfoSignal(s, info)
	try:
		msg  = _('Comienzo a enviar recursos:\n')
		msg += info
		sendToBotDebug(s, msg, debugON_menuRutaComercial)

		executeRoutes(s, rutas)

		msg  = _('Termino de enviar recursos:\n')
		msg += info
		sendToBotDebug(s, msg, debugON_menuRutaComercial)
	except:
		msg = _('Error en:\n{}\nCausa:\n{}').format(info, traceback.format_exc())
		sendToBot(s, msg)
	finally:
		s.logout()



#! /usr/bin/env python3
# -*- coding: utf-8 -*-

import re
import math
import json
import gettext
import traceback
from decimal import *
from ikabot.helpers.process import set_child_mode
from ikabot.helpers.varios import addDot
from ikabot.helpers.gui import enter, banner
from ikabot.helpers.getJson import getCiudad
from ikabot.helpers.signals import setInfoSignal
from ikabot.helpers.planearViajes import waitForArrival
from ikabot.helpers.pedirInfo import getIdsOfCities, read
from ikabot.config import *
from ikabot.helpers.botComm import *
from ikabot.helpers.recursos import *
from ikabot.helpers.tienda import *

t = gettext.translation('comprarRecursos', 
                        localedir, 
                        languages=idiomas,
                        fallback=True)
_ = t.gettext

def asignarRecursoBuscado(s, ciudad):
	print(_('¿Qué recurso quiere comprar?'))
	for indice, bien in enumerate(tipoDeBien):
		print('({:d}) {}'.format(indice+1, bien))
	eleccion = read(min=1, max=5)
	recurso = eleccion - 1
	if recurso == 0:
		recurso = 'resource'
	data = {
	'cityId': ciudad['id'],
	'position': ciudad['pos'],
	'view': 'branchOffice',
	'activeTab': 'bargain',
	'type': 444,
	'searchResource': recurso,
	'range': ciudad['rango'],
	'backgroundView' : 'city',
	'currentCityId': ciudad['id'],
	'templateView': 'branchOffice',
	'currentTab': 'bargain',
	'actionRequest': s.token(),
	'ajax': 1
	}
	rta = s.post(payloadPost=data)
	return eleccion, recurso

def obtenerOfertas(s, ciudad):
	html = getStoreHtml(s, ciudad)
	hits = re.findall(r'short_text80">(.*?) *<br/>\((.*?)\)\s *</td>\s *<td>(\d+)</td>\s *<td>(.*?)/td>\s *<td><img src="skin/resources/icon_(\w+)\.png[\s\S]*?white-space:nowrap;">(\d+)\s[\s\S]*?href="\?view=takeOffer&destinationCityId=(\d+)&oldView=branchOffice&activeTab=bargain&cityId=(\d+)&position=(\d+)&type=(\d+)&resource=(\w+)"', html)
	ofertas = []
	for hit in hits:
		oferta = {
		'ciudadDestino': hit[0],
		'jugadorAComprar' : hit[1],
		'bienesXminuto': int(hit[2]),
		'cantidadDisponible': int(hit[3].replace(',', '').replace('.', '').replace('<', '')),
		'tipo': hit[4],
		'precio': int(hit[5]),
		'destinationCityId': hit[6],
		'cityId': hit[7],
		'position': hit[8],
		'type': hit[9],
		'resource': hit[10]
		}
		ofertas.append(oferta)
	return ofertas

def calcularCosto(ofertas, cantidadAComprar):
	costoTotal = 0
	for oferta in ofertas:
		if cantidadAComprar == 0:
			break
		comprar = oferta['cantidadDisponible'] if oferta['cantidadDisponible'] < cantidadAComprar else cantidadAComprar
		cantidadAComprar -= comprar
		costoTotal += comprar * oferta['precio']
	return costoTotal

def getOro(s, ciudad):
	url = 'view=finances&backgroundView=city&currentCityId={}&templateView=finances&actionRequest={}&ajax=1'.format(ciudad['id'], s.token())
	data = s.post(url)
	json_data = json.loads(data, strict=False)
	oro = json_data[0][1]['headerData']['gold']
	return int(oro.split('.')[0])

def elegirCiudadComercial(ciudades_comerciales):
	print(_('¿Desde cuál ciudad quiere comprar recursos?\n'))
	for i, ciudad in enumerate(ciudades_comerciales):
		print('({:d}) {}'.format(i + 1, ciudad['name']))
	ind = read(min=1, max=len(ciudades_comerciales))
	return ciudades_comerciales[ind - 1]

def comprarRecursos(s,e,fd):
	sys.stdin = os.fdopen(fd)
	try:
		banner()

		ciudades_comerciales = getCiudadesComerciales(s)
		if len(ciudades_comerciales) == 0:
			print(_('No hay una Tienda contruida'))
			enter()
			e.set()
			return

		if len(ciudades_comerciales) == 1:
			ciudad = ciudades_comerciales[0]
		else:
			ciudad = elegirCiudadComercial(ciudades_comerciales)
			banner()

		numRecurso, recurso = asignarRecursoBuscado(s, ciudad)
		banner()

		ofertas = obtenerOfertas(s, ciudad)
		if len(ofertas) == 0:
			print(_('No se encontraron ofertas.'))
			e.set()
			return

		precio_total   = 0
		cantidad_total = 0
		for oferta in ofertas:
			cantidad = oferta['cantidadDisponible']
			unidad   = oferta['precio']
			costo    = cantidad * unidad
			print(_('cantidad :{}').format(addDot(cantidad)))
			print(_('precio   :{:d}').format(unidad))
			print(_('costo    :{}').format(addDot(costo)))
			print('')
			precio_total += costo
			cantidad_total += cantidad

		disponible = ciudad['freeSpaceForResources'][numRecurso - 1]

		print(_('Total disponible para comprar: {}, por {}').format(addDot(cantidad_total), addDot(precio_total)))
		if disponible < cantidad_total:
			print(_('Solo se puede comprar {} por falta de almacenamiento.').format(addDot(disponible)))
			cantidad_total = disponible
		print('')
		cantidadAComprar = read(msg=_('¿Cuánta cantidad comprar? '), min=0, max=cantidad_total)
		if cantidadAComprar == 0:
			e.set()
			return

		oro = getOro(s, ciudad)
		costoTotal = calcularCosto(ofertas, cantidadAComprar)

		print(_('\nOro actual : {}.\nCosto total: {}.\nOro final  : {}.'). format(addDot(oro), addDot(costoTotal), addDot(oro - costoTotal)))
		print(_('¿Proceder? [Y/n]'))
		rta = read(values=['y', 'Y', 'n', 'N', ''])
		if rta.lower() == 'n':
			e.set()
			return

		print(_('Se comprará {}').format(addDot(cantidadAComprar)))
		enter()
	except KeyboardInterrupt:
		e.set()
		return

	set_child_mode(s)
	e.set()

	info = _('\nCompro {} de {} para {}\n').format(addDot(cantidadAComprar), tipoDeBien[numRecurso - 1], ciudad['cityName'])
	setInfoSignal(s, info)
	try:
		do_it(s, ciudad, ofertas, cantidadAComprar)
	except:
		msg = _('Error en:\n{}\nCausa:\n{}').format(info, traceback.format_exc())
		sendToBot(s, msg)
	finally:
		s.logout()

def buy(s, ciudad, oferta, cantidad):
	barcos = int(math.ceil((Decimal(cantidad) / Decimal(500))))
	data_dict = {
	'action': 'transportOperations',
	'function': 'buyGoodsAtAnotherBranchOffice',
	'cityId': oferta['cityId'],
	'destinationCityId': oferta['destinationCityId'],
	'oldView': 'branchOffice',
	'position': ciudad['pos'],
	'avatar2Name': oferta['jugadorAComprar'],
	'city2Name': oferta['ciudadDestino'],
	'type': int(oferta['type']),
	'activeTab': 'bargain',
	'transportDisplayPrice': 0,
	'premiumTransporter': 0,
	'capacity': 5,
	'max_capacity': 5,
	'jetPropulsion': 0,
	'transporters': barcos,
	'backgroundView': 'city',
	'currentCityId': oferta['cityId'],
	'templateView': 'takeOffer',
	'currentTab': 'bargain',
	'actionRequest': s.token(),
	'ajax': 1
	}
	url = 'view=takeOffer&destinationCityId={}&oldView=branchOffice&activeTab=bargain&cityId={}&position={}&type={}&resource={}&backgroundView=city&currentCityId={}&templateView=branchOffice&actionRequest={}&ajax=1'.format(oferta['destinationCityId'], oferta['cityId'], oferta['position'], oferta['type'], oferta['resource'], oferta['cityId'], s.token())
	data = s.post(url)
	html = json.loads(data, strict=False)[1][1][1]
	hits = re.findall(r'"tradegood(\d)Price"\s*value="(\d+)', html)
	for hit in hits:
		data_dict['tradegood{}Price'.format(hit[0])] = int(hit[1])
		data_dict['cargo_tradegood{}'.format(hit[0])] = 0
	hit = re.search(r'"resourcePrice"\s*value="(\d+)', html)
	if hit:
		data_dict['resourcePrice'] = int(hit.group(1))
		data_dict['cargo_resource'] = 0
	resource = oferta['resource']
	if resource == 'resource':
		data_dict['cargo_resource'] = cantidad
	else:
		data_dict['cargo_tradegood{}'.format(resource)] = cantidad
	s.post(payloadPost=data_dict)
	msg = _('Compro {} a {} de {}').format(addDot(cantidad), oferta['ciudadDestino'], oferta['jugadorAComprar'])
	sendToBotDebug(s, msg, debugON_comprarRecursos)

def do_it(s, ciudad, ofertas, cantidadAComprar):
	while True:
		for oferta in ofertas:
			if cantidadAComprar == 0:
				return
			if oferta['cantidadDisponible'] == 0:
				continue
			barcosDisp = waitForArrival(s)
			storageCapacity  = barcosDisp * 500
			comprable_max = storageCapacity if storageCapacity < cantidadAComprar else cantidadAComprar
			compra = comprable_max if oferta['cantidadDisponible'] > comprable_max else oferta['cantidadDisponible']
			cantidadAComprar -= compra
			oferta['cantidadDisponible'] -= compra
			buy(s, ciudad, oferta, compra)
			break # vuelvo a empezar desde el principio
